@@ -13,7 +13,6 @@ use strict;
 use IO::File qw(!/^SEEK/);
 use POSIX;
 use Fcntl;
-use File::lockf;
 use HTML::Mason::Config;
 use Date::Manip;
 
@@ -75,17 +74,14 @@ sub access_data_cache
 	#
 	# Create dump version of store value
 	# MS 7/16/98: No longer needed under MLDBM
-	#
 	#	my $d = new Data::Dumper ([$options{value}]);
 	#	$d->Indent(0);
 	#	$d->Purity(1);
 	#	my $dump = $d->Dumpxs();
 	#	$dump =~ s/\$VAR1\s*=\s*/return /;
-
 	#
 	# Create DB file if necessary
 	# MS 7/16/98: Shouldn't need the following if we trap tie later
-	#
 	#if (!-e $physFile) {
 	#    my %new;
 	#    tie (%new, 'MLDBM', $cacheFile, O_RDWR|O_CREAT, 0664);
@@ -94,14 +90,16 @@ sub access_data_cache
 	#die "cache: cannot create cache file '$cacheFile'\n"
 	#	if (!-f $physFile);
 
+	# Create DB file if necessary
 	tie (%out, 'MLDBM', $cacheFile, O_RDWR|O_CREAT, 0664)
 		or die "cache: cannot create/open cache file '$cacheFile'\n";
 
 	#
 	# Try to get lock on DB file. If not possible, return.
 	#
-	my $outfh = new IO::File "<$physFile" or die "cache: cannot open cache file '$physFile' for locking\n";
-	return if (File::lockf::tlock($outfh) == EAGAIN);
+	my $lockfh = new IO::File ">>$physFile"
+	   or die "cache: cannot open cache file '$physFile' for locking\n";
+	return unless &get_lock($lockfh);
 
 	if ($action eq 'store') {
 	    $out{"$key.contents"} = $options{value};
@@ -120,7 +118,7 @@ sub access_data_cache
 	}
 	# this line causes a bizarre untie/eval bug
 	untie(%out);
-	$outfh->close();
+	$lockfh->close();
 
     #
     # Retrieve
@@ -175,7 +173,7 @@ sub access_data_cache
 	return undef if ($mem->{expires} && $time >= $mem->{expires});
 	if (exists($options{expire_if})) {
 	    my $sub = $options{expire_if};
-	    return undef if (&$sub(key=>$key,lastModified=>$mem->{lastModified}));
+	    return undef if (&$sub($mem->{lastModified}));
 	}
 	if (exists($options{expire_if_older_than})) {
 	    my $compareTime = $options{expire_if_older_than};
@@ -186,3 +184,16 @@ sub access_data_cache
 	die "cache: bad action '$options{action}': must be one of 'store', 'retrieve', or 'expire'\n";
     }
 }
+
+#
+# Returns 1 if the exclusive, non-blocking lock was obtained,
+# undef otherwise.
+#
+sub get_lock {
+	my $fh = shift;
+
+	my $LOCK_EX = 2;
+	my $LOCK_NB = 4;
+	my $LOCK_UN = 8;
+	return flock $fh, $LOCK_EX|$LOCK_NB;
+}
